pub struct Opts {Show 13 fields
pub url: Url,
pub method: Option<String>,
pub param: Option<String>,
pub param_file: Option<String>,
pub user_id: Option<String>,
pub timeout: u64,
pub output_format: String,
pub tunnel: Option<String>,
pub tunnel_path: Option<String>,
pub burst: Option<String>,
pub user_agent: Option<String>,
pub verbose: Option<String>,
pub version: bool,
}Fields
url: UrlUrl to connect to, example tcp://admin@localhost:3755?password=dj4j5HHb, localsocket:path/to/socket
method: Option<String>Method is specified together with path like: shv/path:method
param: Option<String>param_file: Option<String>Read param from a file, takes precedence over --param, pass “-” to read param from
standard input
user_id: Option<String>timeout: u64Timeout in milliseconds, value 0 means wait forever.
output_format: StringOutput format: [ cpon | icpon | chainpack | simple | value | custom “format” ] Placeholders {PATH} {METHOD} {VALUE} in any number and combination will be replaced in format string.
tunnel: Option<String>Create TCP tunnel, SSH like syntax, example: -L 2222:some.host.org:22
tunnel_path: Option<String>Path to the broker’s .app/tunnel where the tunnel should be created.
burst: Option<String>Send N request in M threads, format is N[,M], default M == 1
user_agent: Option<String>Add user-agent string to login parameters
verbose: Option<String>Verbose mode (module, .)
version: boolPrint version and exit